@@ -1,10 +1,10 @@
 import cStringIO
 from PIL import Image
-from libmproxy.protocol.http import decoded
+from libmproxy.models import decoded
 
 
 def response(context, flow):
-    if flow.response.headers.get_first("content-type", "").startswith("image"):
+    if flow.response.headers.get("content-type", "").startswith("image"):
         with decoded(flow.response):  # automatically decode gzipped responses.
             try:
                 s = cStringIO.StringIO(flow.response.content)
@@ -12,6 +12,6 @@ def response(context, flow):
                 s2 = cStringIO.StringIO()
                 img.save(s2, "png")
                 flow.response.content = s2.getvalue()
-                flow.response.headers["content-type"] = ["image/png"]
+                flow.response.headers["content-type"] = "image/png"
             except:  # Unknown image types etc.
                 pass
